<?php declare(strict_types = 1);

namespace DHLParcel\Shipping\Service;

use Shopware\Core\System\SystemConfig\SystemConfigService;

class ConfigService
{
    const CONFIG_DOMAIN = 'DHLParcelShipping';
    const CONFIG_KEY_STATUS = 'status';
    const CONFIG_KEY_WEBHOOKURL = 'webhookurl';

    /**
     * @var SystemConfigService
     */
    protected $systemConfigService;

    /**
     * @param SystemConfigService $systemConfigService
     */
    public function __construct(SystemConfigService $systemConfigService)
    {
        $this->systemConfigService = $systemConfigService;
    }

    /**
     * @return bool
     */
    public function isEnabled(): bool
    {
        return boolval($this->getConfig(self::CONFIG_KEY_STATUS));
    }

    /**
     * @return string
     */
    public function getWebhookUrl(): string
    {
        return strval($this->getConfig(self::CONFIG_KEY_WEBHOOKURL));
    }

    /**
     * @param $key
     * @return mixed|string
     */
    protected function getConfig($key)
    {
        $configs = $this->systemConfigService->all();
        if (!isset($configs[self::CONFIG_DOMAIN])) {
            return '';
        }

        if (!isset($configs[self::CONFIG_DOMAIN]['config'])) {
            return '';
        }

        if (!isset($configs[self::CONFIG_DOMAIN]['config'][$key])) {
            return '';
        }

        return $configs[self::CONFIG_DOMAIN]['config'][$key];
    }
}
